Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Opium_kernel.RockA tiny clone of ruby's Rack protocol in OCaml. Which is slightly more general and inspired by Finagle. It's not imperative to have this to for such a tiny framework but it makes extensions a lot more straightforward
module Service : sig ... endA service is simply a function that returns its result asynchronously
module Filter : sig ... endA filter is a higher order function that transforms a service into another service.
module Request : sig ... endmodule Response : sig ... endmodule Handler : sig ... endA handler is a rock specific service
module Middleware : sig ... endMiddleware is a named, simple filter, that only works on rock requests/response
module App : sig ... end