Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Rock.FilterSourceA filter is a higher order function that transforms a service into another service.
A filter is a higher order function that transforms a service into another service.
type ('req, 'rep, 'req', 'rep') t =
('req, 'rep) Rock.Service.t ->
('req', 'rep') Rock.Service.tval sexp_of_t :
('req -> Sexplib0.Sexp.t) ->
('rep -> Sexplib0.Sexp.t) ->
('req' -> Sexplib0.Sexp.t) ->
('rep' -> Sexplib0.Sexp.t) ->
('req, 'rep, 'req', 'rep') t ->
Sexplib0.Sexp.tval t_of_sexp :
(Sexplib0.Sexp.t -> 'req) ->
(Sexplib0.Sexp.t -> 'rep) ->
(Sexplib0.Sexp.t -> 'req') ->
(Sexplib0.Sexp.t -> 'rep') ->
Sexplib0.Sexp.t ->
('req, 'rep, 'req', 'rep') tA filter is simple when it preserves the type of a service
val sexp_of_simple :
('req -> Sexplib0.Sexp.t) ->
('rep -> Sexplib0.Sexp.t) ->
('req, 'rep) simple ->
Sexplib0.Sexp.tval simple_of_sexp :
(Sexplib0.Sexp.t -> 'req) ->
(Sexplib0.Sexp.t -> 'rep) ->
Sexplib0.Sexp.t ->
('req, 'rep) simpleval apply_all :
('req, 'rep) simple list ->
('req, 'rep) Rock.Service.t ->
('req, 'rep) Rock.Service.t